@@ -49,7 +49,7 @@ class DefaultEventManager : public Common::EventManager, Common::EventObserver {
 	Common::ArtificialEventSource _artificialEventSource;
 
 	Common::Queue<Common::Event> _eventQueue;
-	bool notifyEvent(const Common::Event &ev) {
+	bool notifyEvent(const Common::Event &ev) override {
 		_eventQueue.push(ev);
 		return true;
 	}
@@ -76,25 +76,25 @@ public:
 	DefaultEventManager(Common::EventSource *boss);
 	~DefaultEventManager();
 
-	virtual void init();
-	virtual bool pollEvent(Common::Event &event);
-	virtual void pushEvent(const Common::Event &event);
+	virtual void init() override;
+	virtual bool pollEvent(Common::Event &event) override;
+	virtual void pushEvent(const Common::Event &event) override;
 	virtual void purgeMouseEvents() override;
 
-	virtual Common::Point getMousePos() const { return _mousePos; }
-	virtual int getButtonState() const { return _buttonState; }
-	virtual int getModifierState() const { return _modifierState; }
-	virtual int shouldQuit() const { return _shouldQuit; }
-	virtual int shouldRTL() const { return _shouldRTL; }
-	virtual void resetRTL() { _shouldRTL = false; }
+	virtual Common::Point getMousePos() const override { return _mousePos; }
+	virtual int getButtonState() const override { return _buttonState; }
+	virtual int getModifierState() const override { return _modifierState; }
+	virtual int shouldQuit() const override { return _shouldQuit; }
+	virtual int shouldRTL() const override { return _shouldRTL; }
+	virtual void resetRTL() override { _shouldRTL = false; }
 #ifdef FORCE_RTL
-	virtual void resetQuit() { _shouldQuit = false; }
+	virtual void resetQuit() override { _shouldQuit = false; }
 #endif
 
 #ifdef ENABLE_KEYMAPPER
 	 // IMPORTANT NOTE: This is part of the WIP Keymapper. If you plan to use
 	 // this, please talk to tsoliman and/or LordHoto.
-	virtual Common::Keymapper *getKeymapper() { return _keymapper; }
+	virtual Common::Keymapper *getKeymapper() override { return _keymapper; }
 #endif
 
 	/**
