@@ -40,7 +40,7 @@ const char *lastPathComponent(const Common::String &str) {
 	int offset = str.size();
 
 	if (offset <= 0) {
-		debug(6, "Bad offset");
+		debug(6, "Bad offset!");
 		return 0;
 	}
 
@@ -57,12 +57,12 @@ const char *lastPathComponent(const Common::String &str) {
 
 AmigaOSFilesystemNode::AmigaOSFilesystemNode() {
 	ENTER();
-	_sDisplayName = "Available Disks";
+	_sDisplayName = "Available HDDs/Partitions";
 	_bIsValid = true;
 	_bIsDirectory = true;
 	_sPath = "";
 	_pFileLock = 0;
-	_nProt = 0; // Protection is ignored for the root volume
+	_nProt = 0; // Protection is ignored for the root volume.
 	LEAVE();
 }
 
@@ -71,10 +71,8 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(const Common::String &p) {
 
 	int offset = p.size();
 
-	//assert(offset > 0);
-
 	if (offset <= 0) {
-		debug(6, "Bad offset");
+		debug(6, "Bad offset!");
 		return;
 	}
 
@@ -84,7 +82,20 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(const Common::String &p) {
 	_bIsDirectory = false;
 	_bIsValid = false;
 
-	// Check whether the node exists and if it's a directory
+	// WORKAROUND:
+	// This is a workaround for a bug present in AmigaOS4's
+	// newlib.library 53.30 and lower.
+	// It will be removed once a fixed version of said library is
+	// available to the public.
+	// DESCRIPTION:
+	// We need to explicitly open dos.library and it's IDOS interface.
+	// Otherwise it will hit a NULL pointer with a shared binary build.
+	// The hit will happen on loading a game from any engine, if
+	// more than one engine (shared) plugin is available.
+	DOSBase = IExec->OpenLibrary("dos.library", 0);
+	IDOS = (struct DOSIFace *)IExec->GetInterface(DOSBase, "main", 1, NULL);
+
+	// Check whether the node exists and if it's a directory.
 	struct ExamineData * pExd = IDOS->ExamineObjectTags(EX_StringNameInput,_sPath.c_str(),TAG_END);
 	if (pExd) {
 		_nProt = pExd->Protection;
@@ -93,7 +104,7 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(const Common::String &p) {
 			_pFileLock = IDOS->Lock((CONST_STRPTR)_sPath.c_str(), SHARED_LOCK);
 			_bIsValid = (_pFileLock != 0);
 
-			// Add a trailing slash if needed
+			// Add a trailing slash, if needed.
 			const char c = _sPath.lastChar();
 			if (c != '/' && c != ':')
 				_sPath += '/';
@@ -105,6 +116,11 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(const Common::String &p) {
 		IDOS->FreeDosObject(DOS_EXAMINEDATA, pExd);
 	}
 
+	// WORKAROUND:
+	// Close dos.library and its IDOS interface again.
+	IExec->DropInterface((struct Interface *)IDOS);
+	IExec->CloseLibrary(DOSBase);
+
 	LEAVE();
 }
 
@@ -124,7 +140,7 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(BPTR pLock, const char *pDisplayNam
 
 		if (IDOS->IoErr() != ERROR_LINE_TOO_LONG) {
 			_bIsValid = false;
-			debug(6, "IoErr() != ERROR_LINE_TOO_LONG");
+			debug(6, "IDOS->IoErr() failed - ERROR_LINE_TOO_LONG not matched!");
 			LEAVE();
 			delete[] n;
 			return;
@@ -134,9 +150,10 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(BPTR pLock, const char *pDisplayNam
 		delete[] n;
 	}
 
-	_bIsValid = false;
 	_bIsDirectory = false;
+	_bIsValid = false;
 
+	// Check whether the node exists and if it's a directory.
 	struct ExamineData * pExd = IDOS->ExamineObjectTags(EX_FileLockInput,pLock,TAG_END);
 	if (pExd) {
 		_nProt = pExd->Protection;
@@ -145,6 +162,7 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(BPTR pLock, const char *pDisplayNam
 			_pFileLock = IDOS->DupLock(pLock);
 			_bIsValid = _pFileLock != 0;
 
+			// Add a trailing slash, if needed.
 			const char c = _sPath.lastChar();
 			if (c != '/' && c != ':')
 				_sPath += '/';
@@ -155,13 +173,13 @@ AmigaOSFilesystemNode::AmigaOSFilesystemNode(BPTR pLock, const char *pDisplayNam
 
         IDOS->FreeDosObject(DOS_EXAMINEDATA, pExd);
 	} else {
-		debug(6, "ExamineObject() returned NULL");
+		debug(6, "IDOS->ExamineData() failed - ExamineDosObject returned NULL!");
     }
 
 	LEAVE();
 }
 
-// We need the custom copy constructor because of DupLock()
+// We need the custom copy constructor because of DupLock().
 AmigaOSFilesystemNode::AmigaOSFilesystemNode(const AmigaOSFilesystemNode& node)
 : AbstractFSNode() {
 	ENTER();
@@ -218,7 +236,7 @@ bool AmigaOSFilesystemNode::exists() const {
 AbstractFSNode *AmigaOSFilesystemNode::getChild(const Common::String &n) const {
 	ENTER();
 	if (!_bIsDirectory) {
-		debug(6, "Not a directory");
+		debug(6, "Not a directory!");
 		return 0;
 	}
 
@@ -237,34 +255,32 @@ bool AmigaOSFilesystemNode::getChildren(AbstractFSList &myList, ListMode mode, b
 	ENTER();
 	bool ret = false;
 
-	// TODO: Honor the hidden flag
-	// There is no such thing as a hidden flag in AmigaOS...
-
 	if (!_bIsValid) {
-		debug(6, "Invalid node");
+		debug(6, "Invalid node!");
 		LEAVE();
 		return false; // Empty list
 	}
 
 	if (!_bIsDirectory) {
-		debug(6, "Not a directory");
+		debug(6, "Not a directory!");
 		LEAVE();
 		return false; // Empty list
 	}
 
 	if (isRootNode()) {
-		debug(6, "Root node");
+		debug(6, "Root node!");
 		LEAVE();
 		myList = listVolumes();
 		return true;
 	}
 
-	APTR context = IDOS->ObtainDirContextTags(  EX_FileLockInput,	_pFileLock,
-												EX_DoCurrentDir,	TRUE,  /* for softlinks */
-												EX_DataFields,		(EXF_NAME|EXF_LINK|EXF_TYPE),
-												TAG_END);
+	APTR context = IDOS->ObtainDirContextTags(  	EX_FileLockInput,	_pFileLock,
+							EX_DoCurrentDir,	TRUE,  /* for softlinks */
+							EX_DataFields,		(EXF_NAME|EXF_LINK|EXF_TYPE),
+							TAG_END);
 	if (context) {
-		struct ExamineData * pExd = NULL; // NB: No need to free the value after usage, everything will be dealt with by the DirContext release
+		// No need to free the value after usage, everything will be dealt with by the DirContext release.
+		struct ExamineData * pExd = NULL;
 
 		AmigaOSFilesystemNode *entry;
 		while ( (pExd = IDOS->ExamineDir(context)) ) {
@@ -286,7 +302,7 @@ bool AmigaOSFilesystemNode::getChildren(AbstractFSList &myList, ListMode mode, b
 		}
 
 		if (ERROR_NO_MORE_ENTRIES != IDOS->IoErr() ) {
-			debug(6, "An error occurred during ExamineDir");
+			debug(6, "IDOS->IoErr() failed - ERROR_NO_MORE_ENTRIES!");
 			ret = false;
 		} else {
 			ret = true;
@@ -295,7 +311,7 @@ bool AmigaOSFilesystemNode::getChildren(AbstractFSList &myList, ListMode mode, b
 
 		IDOS->ReleaseDirContext(context);
 	} else {
-		debug(6, "Unable to ObtainDirContext");
+		debug(6, "IDOS->ObtainDirContext() failed!");
 		ret = false;
 	}
 
@@ -308,7 +324,7 @@ AbstractFSNode *AmigaOSFilesystemNode::getParent() const {
 	ENTER();
 
 	if (isRootNode()) {
-		debug(6, "Root node");
+		debug(6, "Root node!");
 		LEAVE();
 		return new AmigaOSFilesystemNode(*this);
 	}
@@ -343,9 +359,9 @@ bool AmigaOSFilesystemNode::isReadable() const {
 	if (!_bIsValid)
 		return false;
 
-	// Regular RWED protection flags are low-active or inverted, thus the negation.
-	// Moreover, a pseudo root filesystem is readable whatever the
-	// protection says.
+	// Regular RWED protection flags are low-active or inverted,
+	// thus the negation. Moreover, a pseudo root filesystem is
+	// readable whatever the protection says.
 	bool readable = !(_nProt & EXDF_OTR_READ) || isRootNode();
 
 	return readable;
@@ -355,9 +371,10 @@ bool AmigaOSFilesystemNode::isWritable() const {
 	if (!_bIsValid)
 		return false;
 
-	// Regular RWED protection flags are low-active or inverted, thus the negation.
-	// Moreover, a pseudo root filesystem is never writable whatever
-	// the protection says (Because of it's pseudo nature).
+	// Regular RWED protection flags are low-active or inverted,
+	// thus the negation. Moreover, a pseudo root filesystem is
+	// never writable whatever the protection says.
+	// (Because of it's pseudo nature).
 	bool writable = !(_nProt & EXDF_OTR_WRITE) && !isRootNode();
 
 	return writable;
@@ -373,7 +390,7 @@ AbstractFSList AmigaOSFilesystemNode::listVolumes() const {
 
 	struct DosList *dosList = IDOS->LockDosList(kLockFlags);
 	if (!dosList) {
-		debug(6, "Cannot lock the DOS list");
+		debug(6, "IDOS->LockDOSList() failed!");
 		LEAVE();
 		return myList;
 	}
@@ -385,18 +402,21 @@ AbstractFSList AmigaOSFilesystemNode::listVolumes() const {
 			dosList->dol_Port) {
 
 			// The original line was
-			//if (dosList->dol_Type == DLT_VOLUME &&
-			//dosList->dol_Name &&
-			//dosList->dol_Task) {
-			// which errored using SDK 53.24 with a 'struct dosList' has no member called 'dol_Task'
-			// The reason for that was that
-			// 1) dol_Task wasn't a task pointer, it is a message port instead
-			// 2) It was redefined to be dol_Port in dos/obsolete.h in afore mentioned SDK
+			//
+			//	if (dosList->dol_Type == DLT_VOLUME &&
+			//		dosList->dol_Name &&
+			//		dosList->dol_Task) {
+			//
+			// which errored using SDK 53.24 with a
+			//	'struct dosList' has no member called 'dol_Task'
+			// The reason for that was, that
+			//	1) dol_Task wasn't a task pointer, it was a message port instead.
+			//	2) it was redefined to be dol_Port in dos/obsolete.h in aforementioned SDK.
 
-			// Copy name to buffer
+			// Copy name to buffer.
 			IDOS->CopyStringBSTRToC(dosList->dol_Name, buffer, MAXPATHLEN);
 
-			// Volume name + '\0'
+			// Volume name + '\0'.
 			char *volName = new char [strlen(buffer) + 1];
 
 			strcpy(volName, buffer);
@@ -408,10 +428,10 @@ AbstractFSList AmigaOSFilesystemNode::listVolumes() const {
 
 				char *devName = new char [MAXPATHLEN];
 
-				// Find device name
+				// Find device name.
 				IDOS->DevNameFromLock(volumeLock, devName, MAXPATHLEN, DN_DEVICEONLY);
 
-				sprintf(buffer, "%s (%s)", volName, devName);
+				snprintf(buffer, MAXPATHLEN, "%s (%s)", volName, devName);
 
 				delete[] devName;
 
