@@ -26,68 +26,39 @@
 #include "common/array.h"
 #include "common/mutex.h"
 #include "common/str.h"
+
 #include "audio/audiostream.h"
+#include "audio/mixer.h"
 
 namespace BladeRunner {
 
 class BladeRunnerEngine;
 class AudioCache;
 
-/*
- * This is a poor imitation of Bladerunner's resource cache
- */
-class AudioCache {
-	struct cacheItem {
-		int32   hash;
-		int     refs;
-		uint    lastAccess;
-		byte   *data;
-		uint32  size;
-	};
-
-	Common::Mutex            _mutex;
-	Common::Array<cacheItem> _cacheItems;
-
-	uint32 _totalSize;
-	uint32 _maxSize;
-	uint32 _accessCounter;
-
-public:
-	AudioCache() :
-		_totalSize(0),
-		_maxSize(2457600),
-		_accessCounter(0) {
-	}
-	~AudioCache();
-
-	bool  canAllocate(uint32 size);
-	bool  dropOldest();
-	byte *findByHash(int32 hash);
-	void  storeByHash(int32 hash, Common::SeekableReadStream *stream);
-
-	void  incRef(int32 hash);
-	void  decRef(int32 hash);
+enum AudioPlayerFlags {
+	kAudioPlayerLoop = 1,
+	kAudioPlayerOverrideVolume = 2
 };
 
 class AudioPlayer {
+#if BLADERUNNER_ORIGINAL_BUGS
 	static const int kTracks = 6;
+#else
+	static const int kTracks = 12;
+#endif // BLADERUNNER_ORIGINAL_BUGS
 
 	struct Track {
 		bool                isActive;
 		int                 channel;
 		int                 priority;
-		int32               hash;
 		int                 volume;
 		int                 pan;
 		Audio::AudioStream *stream;
-
-		Track() : isActive(false) {}
 	};
 
 	BladeRunnerEngine *_vm;
 
 	Common::Mutex _mutex;
-	AudioCache   *_cache;
 	Track         _tracks[kTracks];
 	int           _sfxVolume;
 
@@ -95,17 +66,16 @@ public:
 	AudioPlayer(BladeRunnerEngine *vm);
 	~AudioPlayer();
 
-	enum {
-		LOOP = 1,
-		OVERRIDE_VOLUME = 2
-	};
-
-	int playAud(const Common::String &name, int volume, int panStart, int panEnd, int priority, byte flags = 0);
-	bool isActive(int track);
+	int playAud(const Common::String &name, int volume, int panStart, int panEnd, int priority, byte flags = 0, Audio::Mixer::SoundType type = Audio::Mixer::kSFXSoundType);
+	bool isActive(int track) const;
 	void stop(int track, bool immediately);
 	void stopAll();
-	void adjustVolume(int track, int volume, int delay, bool overrideVolume);
-	void adjustPan(int track, int pan, int delay);
+	void adjustVolume(int track, int volume, uint32 delay, bool overrideVolume);
+	void adjustPan(int track, int pan, uint32 delay);
+
+	void setVolume(int volume);
+	int getVolume() const;
+	void playSample();
 
 private:
 	void remove(int channel);
