@@ -46,42 +46,6 @@ enum {
 	kCTSCount				= 14
 };
 
-static const uint32 kScene3009CannonScopeVideos[] = {
-	0x1010000D,
-	0x340A0049,
-	0x340A0049,
-	0x0282081D,
-	0x0082080D,
-	0x0882080D,
-	0x0882080D,
-	0x0282081D,
-	0x004B000B,
-	0x014B000B,
-	0x044B000B,
-	0x0282081D,
-	0x0282081D,
-	0x0282081D,
-	0x340A0049
-};
-
-static const uint32 kScene3009CannonActionVideos[] = {
-	0x00000000,
-	0x8004001B,	// 1 Fire cannon at wall, it breaks (lowered)
-	0x0004001A,	// 2 Fire cannon at wall, nothing happens (lowered)
-	0x1048404B,	// 3 Fire cannon at emptyness (raised)
-	0x50200109,	// 4 Fire cannon, robot missed (raised)
-	0x12032109,	// 5 Fire cannon, robot hit (raised)
-	0x10201109,	// 6 Fire cannon, no robot (raised)
-	0x000A2030,	// 7 Raise the cannon
-	0x000A0028,	// 8
-	0x000A0028,	// 9
-	0x000A0028,	// 10
-	0x040A1069,	// 11
-	0x040A1069,	// 12
-	0x040A1069,	// 13
-	0x240A1101	// 14 Lower the cannon
-};
-
 static const uint32 kSsScene3009SymbolEdgesFileHashes[] = {
 	0x618827A0,
 	0xB1A92322
