@@ -105,7 +105,7 @@ public:
 		_singleId = "saga";
 	}
 
-	virtual GameDescriptor findGame(const char *gameId) const {
+	PlainGameDescriptor findGame(const char *gameId) const override {
 		return Engines::findGameID(gameId, _gameIds, obsoleteGameIDsTable);
 	}
 
@@ -234,7 +234,7 @@ SaveStateDescriptor SagaMetaEngine::querySaveMetaInfos(const char *target, int s
 		SaveStateDescriptor desc(slot, name);
 
 		// Some older saves were not written in an endian safe fashion.
-		// We try to detect this here by checking for extremly high version values.
+		// We try to detect this here by checking for extremely high version values.
 		// If found, we retry with the data swapped.
 		if (version > 0xFFFFFF) {
 			warning("This savegame is not endian safe, retrying with the data swapped");
@@ -256,7 +256,11 @@ SaveStateDescriptor SagaMetaEngine::querySaveMetaInfos(const char *target, int s
 		}
 
 		if (version >= 6) {
-			Graphics::Surface *const thumbnail = Graphics::loadThumbnail(*in);
+			Graphics::Surface *thumbnail;
+			if (!Graphics::loadThumbnail(*in, thumbnail)) {
+				delete in;
+				return SaveStateDescriptor();
+			}
 			desc.setThumbnail(thumbnail);
 
 			uint32 saveDate = in->readUint32BE();
