@@ -24,9 +24,8 @@
 #define WINTERMUTE_WINTERMUTE_H
 
 #include "engines/engine.h"
-#include "engines/advancedDetector.h"
 #include "gui/debugger.h"
-#include "engines/wintermute/game_description.h"
+#include "common/fs.h"
 
 namespace Wintermute {
 
@@ -34,6 +33,7 @@ class Console;
 class BaseGame;
 class SystemClassRegistry;
 class DebuggerController;
+struct WMEGameDescription;
 
 // our engine debug channels
 enum {
@@ -45,6 +45,11 @@ enum {
 	kWintermuteDebugGeneral = 1 << 5
 };
 
+enum WintermuteGameFeatures {
+ 	/** A game with low-spec resources. */
+ 	GF_LOWSPEC_ASSETS       = 1 << 0
+};
+
 class WintermuteEngine : public Engine {
 public:
 	WintermuteEngine(OSystem *syst, const WMEGameDescription *desc);
