@@ -20,9 +20,11 @@
  *
  */
 
-#include "common/scummsys.h"
 #include "zvision/graphics/render_table.h"
+
+#include "common/math.h"
 #include "common/rect.h"
+#include "common/scummsys.h"
 #include "graphics/colormasks.h"
 
 namespace ZVision {
@@ -139,12 +141,18 @@ void RenderTable::generateRenderTable() {
 }
 
 void RenderTable::generatePanoramaLookupTable() {
-	memset(_internalBuffer, 0, _numRows * _numColumns * sizeof(uint16));
+	for (uint y = 0; y < _numRows; y++) {
+		for (uint x = 0; x < _numColumns; x++) {
+			uint32 index = y * _numColumns + x;
+			_internalBuffer[index].x = 0;
+			_internalBuffer[index].y = 0;
+		}
+	}
 
 	float halfWidth = (float)_numColumns / 2.0f;
 	float halfHeight = (float)_numRows / 2.0f;
 
-	float fovInRadians = (_panoramaOptions.fieldOfView * M_PI / 180.0f);
+	float fovInRadians = Common::deg2rad<float>(_panoramaOptions.fieldOfView);
 	float cylinderRadius = halfHeight / tan(fovInRadians);
 
 	for (uint x = 0; x < _numColumns; ++x) {
@@ -176,7 +184,7 @@ void RenderTable::generateTiltLookupTable() {
 	float halfWidth = (float)_numColumns / 2.0f;
 	float halfHeight = (float)_numRows / 2.0f;
 
-	float fovInRadians = (_tiltOptions.fieldOfView * M_PI / 180.0f);
+	float fovInRadians = Common::deg2rad<float>(_tiltOptions.fieldOfView);
 	float cylinderRadius = halfWidth / tan(fovInRadians);
 	_tiltOptions.gap = cylinderRadius * atan2((float)(halfHeight / cylinderRadius), 1.0f) * _tiltOptions.linearScale;
 
