@@ -21,6 +21,7 @@
  */
 
 #include "gui/remotebrowser.h"
+#include "gui/gui-manager.h"
 #include "gui/widgets/list.h"
 
 #include "common/config-manager.h"
@@ -28,9 +29,9 @@
 #include "common/algorithm.h"
 
 #include "common/translation.h"
-#include <backends/networking/curl/request.h>
-#include <backends/cloud/storage.h>
-#include <backends/cloud/cloudmanager.h>
+#include "backends/networking/curl/request.h"
+#include "backends/cloud/storage.h"
+#include "backends/cloud/cloudmanager.h"
 #include "message.h"
 
 namespace GUI {
@@ -162,7 +163,7 @@ void RemoteBrowserDialog::updateListing() {
 	_fileList->setEnabled(!_navigationLocked);
 
 	// Finally, redraw
-	draw();
+	g_gui.scheduleTopDialogRedraw();
 }
 
 void RemoteBrowserDialog::goUp() {
